@@ -1,4 +1,4 @@
-fdpca = function (x, y, order = 2, ngrid = 500, method = "M", mean = mean, 
+fdpca <- function (x, y, order = 2, ngrid = 500, method = "M", mean = mean, 
     level = level, lambda = 2.3262, iter = 1, ...) 
 {
 	xnam = x
@@ -149,4 +149,4 @@ fdpca = function (x, y, order = 2, ngrid = 500, method = "M", mean = mean,
     return(list(naindex = as.numeric(which(miss)), basis = basiscomb, coeff = coeff, varprop = varprop, 
         weights = w/mean(w), v = v, basis2 = basis2comb, coeff2 = coeff2, 
         mean.se = axse))
-}
\ No newline at end of file
+}
